@@ -44,7 +44,7 @@
 #include <gst/gst.h>
 #include <gst/interfaces/mixer.h>
 
-#include <profiles/gnome-media-profiles.h>
+#include <libgnome-media-profiles/gnome-media-profiles.h>
 
 #include "gsr-window.h"
 
@@ -1317,7 +1317,7 @@ record_cb (GtkAction *action,
 		shutdown_pipeline (priv->record);
 		if (!make_record_source (window))
 			return;
-		current_source = gtk_combo_box_get_active_text (GTK_COMBO_BOX (window->priv->input));
+		current_source = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (window->priv->input));
 		fill_record_input (window, current_source);
 	}
 
@@ -1846,7 +1846,7 @@ record_input_changed_cb (GtkComboBox *input, GSRWindow *window)
 	GstMixerTrack *t = NULL, *new = NULL;
 	static GstMixerTrack *selected = NULL;
 
-	text = gtk_combo_box_get_active_text (input);
+	text = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (input));
 	GST_DEBUG ("record input changed to '%s'", GST_STR_NULL (text));
 
 	if (text == NULL)
@@ -1918,7 +1918,7 @@ fill_record_input (GSRWindow *window, gchar *selected)
 		if (t->label == NULL)
 			continue;
 		if (t->flags & GST_MIXER_TRACK_INPUT) {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (window->priv->input), t->label);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (window->priv->input), t->label);
 			++i;
 		}
 		if (t->flags & GST_MIXER_TRACK_RECORD) {
@@ -2361,7 +2361,7 @@ gsr_window_init (GSRWindow *window)
 	gtk_misc_set_alignment (GTK_MISC (priv->input_label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->input_label, FALSE, FALSE, 0);
 
-	priv->input = gtk_combo_box_new_text ();
+	priv->input = gtk_combo_box_text_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->input_label), priv->input);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->input, TRUE, TRUE, 0);
 
